parse_file

Function parse_file 

pub fn parse_file(file: &mut File) -> Result<Vec<TestSuite>, Error>
Parse the given file for tests and test suites.

A vector of test suites is returned on successful parsing, otherwise a parsing error is returned.