[−][src]Module serial_unit_testing::utils
Enums
| NewlineFormat | Newline format type |
| TextFormat | Text format type for radix string conversion. |
Functions
| bytes_from_binary_string | Convert a binary string into a vector of bytes. |
| bytes_from_decimal_string | Convert a decimal string into a vector of bytes |
| bytes_from_hex_string | Convert a hexadecimal string into a vector of bytes. |
| bytes_from_octal_string | Convert a octal string into a vector of bytes |
| bytes_from_radix_string | Convert a radix string into a vector of bytes. |
| escape_text | Escape given string |
| print_radix_string | Print a vector of bytes in given format. |
| radix_string | Convert a vector of bytes into a radix string with given text format. |