pub fn radix_string(buffer: &[u8], text_format: &TextFormat) -> Result<String>Expand description
Convert a vector of bytes into a radix string with given text format.
pub fn radix_string(buffer: &[u8], text_format: &TextFormat) -> Result<String>Convert a vector of bytes into a radix string with given text format.