pub fn add_newline(
text: &mut String,
text_format: TextFormat,
newline_format: NewlineFormat,
)Expand description
Add newline characters to the end of the string.
The newline characters will be added in the given text format.
pub fn add_newline(
text: &mut String,
text_format: TextFormat,
newline_format: NewlineFormat,
)Add newline characters to the end of the string.
The newline characters will be added in the given text format.